/* This program finds the average ocean depth in each half
   (separated by the diagonal) of a square section of the ocean.
   and the overall average depth.

   Input (keyboard): the file name
   Input (file):     the elements of array depth
   Output (screen):  the array depth in table format, northAverage, 
                     southAverage, and overallAverage 
-----------------------------------------------------------------------*/

#include <iostream>       // istream, cin, cout, >>, <<
#include <iomanip>        // setw()
#include <fstream>        // ifstream
#include <cassert>        // cassert()
#include <string>         // string
using namespace std;

int main()
{
  const int LENGTH = 11,
            WIDTH = 11,
            TOTAL_READINGS = LENGTH * WIDTH;
  double depth[LENGTH][WIDTH];   // depth array
  string fileName;                        // file of depth readings
 
  cout << "Enter name of file containing depth readings: ";
  cin >> fileName;
  ifstream fin(fileName.data());
  assert(fin.is_open());

  for(int i = 0; i < LENGTH; i++)
    for (int j = 0; j < WIDTH; j++)
      fin >> depth[i][j];

// Calculate the north, south, diagonal, and overall sums
// Note: It is assumed that the elements on the diagonal are
//       included in the overall average but not in either half.

  double overallSum = 0, 
         northSum = 0,
         southSum = 0,
         diagonalsum = 0;

  for (int i = 0; i < LENGTH; i++)
  {
    for (int j = 1; j < WIDTH; j++)
    {
      // Add entries below diagonal to southSum
      if (i > 0 && j < i)
	southSum += depth[i][j];

      // Add entries above diagonal to northSum
      if (i  < LENGTH - 1 && j > i)
	northSum += depth[i][j];
    }
    // Add entries on diagonal to northSum
    diagonalsum += depth[i][i];
  }
  overallSum = northSum + southSum + diagonalsum;

  // Calculate the north, south, and overall average depths
  int readingsPerHalf = (TOTAL_READINGS - LENGTH) / 2;
  double northAverage = northSum / readingsPerHalf,
         southAverage = southSum / readingsPerHalf,
         overallAverage = overallSum / (TOTAL_READINGS) ;

  // Display the depth array and the average depths
	 cout <<  "\n\t\t\t\tOCEAN DEPTHS"
              << "\n\t\t\t\t============\n"
	      << setprecision(1) << fixed << showpoint;

  for (int i = 0; i < LENGTH; i++)
  {
    for (int j = 0; j < WIDTH; j++)
      cout << setw(6) << depth[i][j];
    cout << "\n\n";
  }
  cout << "Northern half average depth: " << northAverage << " meters\n\n"
       << "Southern half average depth: " << southAverage << " meters\n\n"
       << "Overall average depth: " <<  overallAverage << " meters\n";
}
